@@ -15,19 +15,27 @@ type Writer interface {
 	LengthActive() int
 	LengthDone() int
 	LengthInQueue() int
+	Log(msg string, a ...interface{})
 	SetAutoStop(autoStop bool)
 	SetMessageWidth(width int)
 	SetNumTrackersExpected(numTrackers int)
 	SetOutputWriter(output io.Writer)
+	SetPinnedMessages(messages ...string)
 	SetSortBy(sortBy SortBy)
 	SetStyle(style Style)
 	SetTrackerLength(length int)
 	SetTrackerPosition(position Position)
+	// Deprecated: in favor of Style().Visibility.ETA
 	ShowETA(show bool)
+	// Deprecated: in favor of Style().Visibility.TrackerOverall
 	ShowOverallTracker(show bool)
+	// Deprecated: in favor of Style().Visibility.Percentage
 	ShowPercentage(show bool)
+	// Deprecated: in favor of Style().Visibility.Time
 	ShowTime(show bool)
+	// Deprecated: in favor of Style().Visibility.Tracker
 	ShowTracker(show bool)
+	// Deprecated: in favor of Style().Visibility.Value
 	ShowValue(show bool)
 	SetUpdateFrequency(frequency time.Duration)
 	Stop()
