@@ -533,11 +533,13 @@ var (
 
 // ColorOptions defines the ANSI colors to use for parts of the Table.
 type ColorOptions struct {
-	IndexColumn  text.Colors // index-column colors (row #, etc.)
+	Border       text.Colors // borders (if nil, uses one of the below)
 	Footer       text.Colors // footer row(s) colors
 	Header       text.Colors // header row(s) colors
+	IndexColumn  text.Colors // index-column colors (row #, etc.)
 	Row          text.Colors // regular row(s) colors
 	RowAlternate text.Colors // regular row(s) colors for the even-numbered rows
+	Separator    text.Colors // separators (if nil, uses one of the above)
 }
 
 var (
@@ -552,18 +554,18 @@ var (
 
 	// ColorOptionsBlackOnBlueWhite renders Black text on Blue/White background.
 	ColorOptionsBlackOnBlueWhite = ColorOptions{
-		IndexColumn:  text.Colors{text.BgHiBlue, text.FgBlack},
 		Footer:       text.Colors{text.BgBlue, text.FgBlack},
 		Header:       text.Colors{text.BgHiBlue, text.FgBlack},
+		IndexColumn:  text.Colors{text.BgHiBlue, text.FgBlack},
 		Row:          text.Colors{text.BgHiWhite, text.FgBlack},
 		RowAlternate: text.Colors{text.BgWhite, text.FgBlack},
 	}
 
 	// ColorOptionsBlackOnCyanWhite renders Black text on Cyan/White background.
 	ColorOptionsBlackOnCyanWhite = ColorOptions{
-		IndexColumn:  text.Colors{text.BgHiCyan, text.FgBlack},
 		Footer:       text.Colors{text.BgCyan, text.FgBlack},
 		Header:       text.Colors{text.BgHiCyan, text.FgBlack},
+		IndexColumn:  text.Colors{text.BgHiCyan, text.FgBlack},
 		Row:          text.Colors{text.BgHiWhite, text.FgBlack},
 		RowAlternate: text.Colors{text.BgWhite, text.FgBlack},
 	}
@@ -571,9 +573,9 @@ var (
 	// ColorOptionsBlackOnGreenWhite renders Black text on Green/White
 	// background.
 	ColorOptionsBlackOnGreenWhite = ColorOptions{
-		IndexColumn:  text.Colors{text.BgHiGreen, text.FgBlack},
 		Footer:       text.Colors{text.BgGreen, text.FgBlack},
 		Header:       text.Colors{text.BgHiGreen, text.FgBlack},
+		IndexColumn:  text.Colors{text.BgHiGreen, text.FgBlack},
 		Row:          text.Colors{text.BgHiWhite, text.FgBlack},
 		RowAlternate: text.Colors{text.BgWhite, text.FgBlack},
 	}
@@ -581,18 +583,18 @@ var (
 	// ColorOptionsBlackOnMagentaWhite renders Black text on Magenta/White
 	// background.
 	ColorOptionsBlackOnMagentaWhite = ColorOptions{
-		IndexColumn:  text.Colors{text.BgHiMagenta, text.FgBlack},
 		Footer:       text.Colors{text.BgMagenta, text.FgBlack},
 		Header:       text.Colors{text.BgHiMagenta, text.FgBlack},
+		IndexColumn:  text.Colors{text.BgHiMagenta, text.FgBlack},
 		Row:          text.Colors{text.BgHiWhite, text.FgBlack},
 		RowAlternate: text.Colors{text.BgWhite, text.FgBlack},
 	}
 
 	// ColorOptionsBlackOnRedWhite renders Black text on Red/White background.
 	ColorOptionsBlackOnRedWhite = ColorOptions{
-		IndexColumn:  text.Colors{text.BgHiRed, text.FgBlack},
 		Footer:       text.Colors{text.BgRed, text.FgBlack},
 		Header:       text.Colors{text.BgHiRed, text.FgBlack},
+		IndexColumn:  text.Colors{text.BgHiRed, text.FgBlack},
 		Row:          text.Colors{text.BgHiWhite, text.FgBlack},
 		RowAlternate: text.Colors{text.BgWhite, text.FgBlack},
 	}
@@ -600,27 +602,27 @@ var (
 	// ColorOptionsBlackOnYellowWhite renders Black text on Yellow/White
 	// background.
 	ColorOptionsBlackOnYellowWhite = ColorOptions{
-		IndexColumn:  text.Colors{text.BgHiYellow, text.FgBlack},
 		Footer:       text.Colors{text.BgYellow, text.FgBlack},
 		Header:       text.Colors{text.BgHiYellow, text.FgBlack},
+		IndexColumn:  text.Colors{text.BgHiYellow, text.FgBlack},
 		Row:          text.Colors{text.BgHiWhite, text.FgBlack},
 		RowAlternate: text.Colors{text.BgWhite, text.FgBlack},
 	}
 
 	// ColorOptionsBlueWhiteOnBlack renders Blue/White text on Black background.
 	ColorOptionsBlueWhiteOnBlack = ColorOptions{
-		IndexColumn:  text.Colors{text.FgHiBlue, text.BgHiBlack},
 		Footer:       text.Colors{text.FgBlue, text.BgHiBlack},
 		Header:       text.Colors{text.FgHiBlue, text.BgHiBlack},
+		IndexColumn:  text.Colors{text.FgHiBlue, text.BgHiBlack},
 		Row:          text.Colors{text.FgHiWhite, text.BgBlack},
 		RowAlternate: text.Colors{text.FgWhite, text.BgBlack},
 	}
 
 	// ColorOptionsCyanWhiteOnBlack renders Cyan/White text on Black background.
 	ColorOptionsCyanWhiteOnBlack = ColorOptions{
-		IndexColumn:  text.Colors{text.FgHiCyan, text.BgHiBlack},
 		Footer:       text.Colors{text.FgCyan, text.BgHiBlack},
 		Header:       text.Colors{text.FgHiCyan, text.BgHiBlack},
+		IndexColumn:  text.Colors{text.FgHiCyan, text.BgHiBlack},
 		Row:          text.Colors{text.FgHiWhite, text.BgBlack},
 		RowAlternate: text.Colors{text.FgWhite, text.BgBlack},
 	}
@@ -628,9 +630,9 @@ var (
 	// ColorOptionsGreenWhiteOnBlack renders Green/White text on Black
 	// background.
 	ColorOptionsGreenWhiteOnBlack = ColorOptions{
-		IndexColumn:  text.Colors{text.FgHiGreen, text.BgHiBlack},
 		Footer:       text.Colors{text.FgGreen, text.BgHiBlack},
 		Header:       text.Colors{text.FgHiGreen, text.BgHiBlack},
+		IndexColumn:  text.Colors{text.FgHiGreen, text.BgHiBlack},
 		Row:          text.Colors{text.FgHiWhite, text.BgBlack},
 		RowAlternate: text.Colors{text.FgWhite, text.BgBlack},
 	}
@@ -638,18 +640,18 @@ var (
 	// ColorOptionsMagentaWhiteOnBlack renders Magenta/White text on Black
 	// background.
 	ColorOptionsMagentaWhiteOnBlack = ColorOptions{
-		IndexColumn:  text.Colors{text.FgHiMagenta, text.BgHiBlack},
 		Footer:       text.Colors{text.FgMagenta, text.BgHiBlack},
 		Header:       text.Colors{text.FgHiMagenta, text.BgHiBlack},
+		IndexColumn:  text.Colors{text.FgHiMagenta, text.BgHiBlack},
 		Row:          text.Colors{text.FgHiWhite, text.BgBlack},
 		RowAlternate: text.Colors{text.FgWhite, text.BgBlack},
 	}
 
 	// ColorOptionsRedWhiteOnBlack renders Red/White text on Black background.
 	ColorOptionsRedWhiteOnBlack = ColorOptions{
-		IndexColumn:  text.Colors{text.FgHiRed, text.BgHiBlack},
 		Footer:       text.Colors{text.FgRed, text.BgHiBlack},
 		Header:       text.Colors{text.FgHiRed, text.BgHiBlack},
+		IndexColumn:  text.Colors{text.FgHiRed, text.BgHiBlack},
 		Row:          text.Colors{text.FgHiWhite, text.BgBlack},
 		RowAlternate: text.Colors{text.FgWhite, text.BgBlack},
 	}
@@ -657,9 +659,9 @@ var (
 	// ColorOptionsYellowWhiteOnBlack renders Yellow/White text on Black
 	// background.
 	ColorOptionsYellowWhiteOnBlack = ColorOptions{
-		IndexColumn:  text.Colors{text.FgHiYellow, text.BgHiBlack},
 		Footer:       text.Colors{text.FgYellow, text.BgHiBlack},
 		Header:       text.Colors{text.FgHiYellow, text.BgHiBlack},
+		IndexColumn:  text.Colors{text.FgHiYellow, text.BgHiBlack},
 		Row:          text.Colors{text.FgHiWhite, text.BgBlack},
 		RowAlternate: text.Colors{text.FgWhite, text.BgBlack},
 	}
@@ -703,6 +705,10 @@ var (
 // Options defines the global options that determine how the Table is
 // rendered.
 type Options struct {
+	// DoNotColorBordersAndSeparators disables coloring all the borders and row
+	// or column separators.
+	DoNotColorBordersAndSeparators bool
+
 	// DrawBorder enables or disables drawing the border around the Table.
 	// Example of a table where it is disabled:
 	//     # │ FIRST NAME │ LAST NAME │ SALARY │
